# geringoso
A Spanish to Geringoso library and filter

Exampe usage:

    $ geringoso hola, sol
    hopolapa, sopol
    $ head -n 7 hombres_necios.txt | geringoso


        Hopombrepes nepeciopos quepe apacupusápais
        apa lapa mupujeper sipin rapazópon
        sipin veper quepe sopois lapa opocapasiópon
        depe lopo mipismopo quepe cupulpápais:

